# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.devices.bluetooth
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage.streams

class BluetoothLEAdvertisementFlags(enum.IntFlag):
    NONE = 0
    LIMITED_DISCOVERABLE_MODE = 0x1
    GENERAL_DISCOVERABLE_MODE = 0x2
    CLASSIC_NOT_SUPPORTED = 0x4
    DUAL_MODE_CONTROLLER_CAPABLE = 0x8
    DUAL_MODE_HOST_CAPABLE = 0x10

class BluetoothLEAdvertisementPublisherStatus(enum.IntEnum):
    CREATED = 0
    WAITING = 1
    STARTED = 2
    STOPPING = 3
    STOPPED = 4
    ABORTED = 5

class BluetoothLEAdvertisementType(enum.IntEnum):
    CONNECTABLE_UNDIRECTED = 0
    CONNECTABLE_DIRECTED = 1
    SCANNABLE_UNDIRECTED = 2
    NON_CONNECTABLE_UNDIRECTED = 3
    SCAN_RESPONSE = 4
    EXTENDED = 5

class BluetoothLEAdvertisementWatcherStatus(enum.IntEnum):
    CREATED = 0
    STARTED = 1
    STOPPING = 2
    STOPPED = 3
    ABORTED = 4

class BluetoothLEScanningMode(enum.IntEnum):
    PASSIVE = 0
    ACTIVE = 1
    NONE = 2

Self = typing.TypeVar('Self')

class BluetoothLEAdvertisement(winsdk.system.Object):
    local_name: str
    flags: typing.Optional[typing.Optional[BluetoothLEAdvertisementFlags]]
    data_sections: typing.Optional[winsdk.windows.foundation.collections.IVector[BluetoothLEAdvertisementDataSection]]
    manufacturer_data: typing.Optional[winsdk.windows.foundation.collections.IVector[BluetoothLEManufacturerData]]
    service_uuids: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.system.Guid]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BluetoothLEAdvertisement: ...
    def __new__(cls: typing.Type[BluetoothLEAdvertisement]) -> BluetoothLEAdvertisement:...
    def get_manufacturer_data_by_company_id(self, company_id: winsdk.system.UInt16) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[BluetoothLEManufacturerData]]: ...
    def get_sections_by_type(self, type: winsdk.system.UInt8) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[BluetoothLEAdvertisementDataSection]]: ...

class BluetoothLEAdvertisementBytePattern(winsdk.system.Object):
    offset: winsdk.system.Int16
    data_type: winsdk.system.UInt8
    data: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BluetoothLEAdvertisementBytePattern: ...
    @typing.overload
    def __new__(cls: typing.Type[BluetoothLEAdvertisementBytePattern]) -> BluetoothLEAdvertisementBytePattern:...
    @typing.overload
    def __new__(cls: typing.Type[BluetoothLEAdvertisementBytePattern], data_type: winsdk.system.UInt8, offset: winsdk.system.Int16, data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> BluetoothLEAdvertisementBytePattern:...

class BluetoothLEAdvertisementDataSection(winsdk.system.Object):
    data_type: winsdk.system.UInt8
    data: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BluetoothLEAdvertisementDataSection: ...
    @typing.overload
    def __new__(cls: typing.Type[BluetoothLEAdvertisementDataSection]) -> BluetoothLEAdvertisementDataSection:...
    @typing.overload
    def __new__(cls: typing.Type[BluetoothLEAdvertisementDataSection], data_type: winsdk.system.UInt8, data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> BluetoothLEAdvertisementDataSection:...

class BluetoothLEAdvertisementDataTypes(winsdk.system.Object):
    advertising_interval: typing.ClassVar[winsdk.system.UInt8]
    appearance: typing.ClassVar[winsdk.system.UInt8]
    complete_local_name: typing.ClassVar[winsdk.system.UInt8]
    complete_service128_bit_uuids: typing.ClassVar[winsdk.system.UInt8]
    complete_service16_bit_uuids: typing.ClassVar[winsdk.system.UInt8]
    complete_service32_bit_uuids: typing.ClassVar[winsdk.system.UInt8]
    flags: typing.ClassVar[winsdk.system.UInt8]
    incomplete_service128_bit_uuids: typing.ClassVar[winsdk.system.UInt8]
    incomplete_service16_bit_uuids: typing.ClassVar[winsdk.system.UInt8]
    incomplete_service32_bit_uuids: typing.ClassVar[winsdk.system.UInt8]
    manufacturer_specific_data: typing.ClassVar[winsdk.system.UInt8]
    peripheral_connection_interval_range: typing.ClassVar[winsdk.system.UInt8]
    public_target_address: typing.ClassVar[winsdk.system.UInt8]
    random_target_address: typing.ClassVar[winsdk.system.UInt8]
    service_data128_bit_uuids: typing.ClassVar[winsdk.system.UInt8]
    service_data16_bit_uuids: typing.ClassVar[winsdk.system.UInt8]
    service_data32_bit_uuids: typing.ClassVar[winsdk.system.UInt8]
    service_solicitation128_bit_uuids: typing.ClassVar[winsdk.system.UInt8]
    service_solicitation16_bit_uuids: typing.ClassVar[winsdk.system.UInt8]
    service_solicitation32_bit_uuids: typing.ClassVar[winsdk.system.UInt8]
    shortened_local_name: typing.ClassVar[winsdk.system.UInt8]
    tx_power_level: typing.ClassVar[winsdk.system.UInt8]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BluetoothLEAdvertisementDataTypes: ...

class BluetoothLEAdvertisementFilter(winsdk.system.Object):
    advertisement: typing.Optional[BluetoothLEAdvertisement]
    byte_patterns: typing.Optional[winsdk.windows.foundation.collections.IVector[BluetoothLEAdvertisementBytePattern]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BluetoothLEAdvertisementFilter: ...
    def __new__(cls: typing.Type[BluetoothLEAdvertisementFilter]) -> BluetoothLEAdvertisementFilter:...

class BluetoothLEAdvertisementPublisher(winsdk.system.Object):
    advertisement: typing.Optional[BluetoothLEAdvertisement]
    status: BluetoothLEAdvertisementPublisherStatus
    use_extended_advertisement: winsdk.system.Boolean
    preferred_transmit_power_level_in_d_bm: typing.Optional[typing.Optional[winsdk.system.Int16]]
    is_anonymous: winsdk.system.Boolean
    include_transmit_power_level: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BluetoothLEAdvertisementPublisher: ...
    @typing.overload
    def __new__(cls: typing.Type[BluetoothLEAdvertisementPublisher]) -> BluetoothLEAdvertisementPublisher:...
    @typing.overload
    def __new__(cls: typing.Type[BluetoothLEAdvertisementPublisher], advertisement: typing.Optional[BluetoothLEAdvertisement]) -> BluetoothLEAdvertisementPublisher:...
    def start(self) -> None: ...
    def stop(self) -> None: ...
    def add_status_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[BluetoothLEAdvertisementPublisher, BluetoothLEAdvertisementPublisherStatusChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_status_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class BluetoothLEAdvertisementPublisherStatusChangedEventArgs(winsdk.system.Object):
    error: winsdk.windows.devices.bluetooth.BluetoothError
    status: BluetoothLEAdvertisementPublisherStatus
    selected_transmit_power_level_in_d_bm: typing.Optional[typing.Optional[winsdk.system.Int16]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BluetoothLEAdvertisementPublisherStatusChangedEventArgs: ...

class BluetoothLEAdvertisementReceivedEventArgs(winsdk.system.Object):
    advertisement: typing.Optional[BluetoothLEAdvertisement]
    advertisement_type: BluetoothLEAdvertisementType
    bluetooth_address: winsdk.system.UInt64
    raw_signal_strength_in_d_bm: winsdk.system.Int16
    timestamp: datetime.datetime
    bluetooth_address_type: winsdk.windows.devices.bluetooth.BluetoothAddressType
    is_anonymous: winsdk.system.Boolean
    is_connectable: winsdk.system.Boolean
    is_directed: winsdk.system.Boolean
    is_scan_response: winsdk.system.Boolean
    is_scannable: winsdk.system.Boolean
    transmit_power_level_in_d_bm: typing.Optional[typing.Optional[winsdk.system.Int16]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BluetoothLEAdvertisementReceivedEventArgs: ...

class BluetoothLEAdvertisementWatcher(winsdk.system.Object):
    signal_strength_filter: typing.Optional[winsdk.windows.devices.bluetooth.BluetoothSignalStrengthFilter]
    scanning_mode: BluetoothLEScanningMode
    advertisement_filter: typing.Optional[BluetoothLEAdvertisementFilter]
    max_out_of_range_timeout: datetime.timedelta
    max_sampling_interval: datetime.timedelta
    min_out_of_range_timeout: datetime.timedelta
    min_sampling_interval: datetime.timedelta
    status: BluetoothLEAdvertisementWatcherStatus
    allow_extended_advertisements: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BluetoothLEAdvertisementWatcher: ...
    @typing.overload
    def __new__(cls: typing.Type[BluetoothLEAdvertisementWatcher]) -> BluetoothLEAdvertisementWatcher:...
    @typing.overload
    def __new__(cls: typing.Type[BluetoothLEAdvertisementWatcher], advertisement_filter: typing.Optional[BluetoothLEAdvertisementFilter]) -> BluetoothLEAdvertisementWatcher:...
    def start(self) -> None: ...
    def stop(self) -> None: ...
    def add_received(self, handler: winsdk.windows.foundation.TypedEventHandler[BluetoothLEAdvertisementWatcher, BluetoothLEAdvertisementReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_stopped(self, handler: winsdk.windows.foundation.TypedEventHandler[BluetoothLEAdvertisementWatcher, BluetoothLEAdvertisementWatcherStoppedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_stopped(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class BluetoothLEAdvertisementWatcherStoppedEventArgs(winsdk.system.Object):
    error: winsdk.windows.devices.bluetooth.BluetoothError
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BluetoothLEAdvertisementWatcherStoppedEventArgs: ...

class BluetoothLEManufacturerData(winsdk.system.Object):
    data: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    company_id: winsdk.system.UInt16
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BluetoothLEManufacturerData: ...
    @typing.overload
    def __new__(cls: typing.Type[BluetoothLEManufacturerData]) -> BluetoothLEManufacturerData:...
    @typing.overload
    def __new__(cls: typing.Type[BluetoothLEManufacturerData], company_id: winsdk.system.UInt16, data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> BluetoothLEManufacturerData:...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.globalization
import winsdk.windows.storage

class SpeechContinuousRecognitionMode(enum.IntEnum):
    DEFAULT = 0
    PAUSE_ON_RECOGNITION = 1

class SpeechRecognitionAudioProblem(enum.IntEnum):
    NONE = 0
    TOO_NOISY = 1
    NO_SIGNAL = 2
    TOO_LOUD = 3
    TOO_QUIET = 4
    TOO_FAST = 5
    TOO_SLOW = 6

class SpeechRecognitionConfidence(enum.IntEnum):
    HIGH = 0
    MEDIUM = 1
    LOW = 2
    REJECTED = 3

class SpeechRecognitionConstraintProbability(enum.IntEnum):
    DEFAULT = 0
    MIN = 1
    MAX = 2

class SpeechRecognitionConstraintType(enum.IntEnum):
    TOPIC = 0
    LIST = 1
    GRAMMAR = 2
    VOICE_COMMAND_DEFINITION = 3

class SpeechRecognitionResultStatus(enum.IntEnum):
    SUCCESS = 0
    TOPIC_LANGUAGE_NOT_SUPPORTED = 1
    GRAMMAR_LANGUAGE_MISMATCH = 2
    GRAMMAR_COMPILATION_FAILURE = 3
    AUDIO_QUALITY_FAILURE = 4
    USER_CANCELED = 5
    UNKNOWN = 6
    TIMEOUT_EXCEEDED = 7
    PAUSE_LIMIT_EXCEEDED = 8
    NETWORK_FAILURE = 9
    MICROPHONE_UNAVAILABLE = 10

class SpeechRecognitionScenario(enum.IntEnum):
    WEB_SEARCH = 0
    DICTATION = 1
    FORM_FILLING = 2

class SpeechRecognizerState(enum.IntEnum):
    IDLE = 0
    CAPTURING = 1
    PROCESSING = 2
    SOUND_STARTED = 3
    SOUND_ENDED = 4
    SPEECH_DETECTED = 5
    PAUSED = 6

Self = typing.TypeVar('Self')

class SpeechContinuousRecognitionCompletedEventArgs(winsdk.system.Object):
    status: SpeechRecognitionResultStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechContinuousRecognitionCompletedEventArgs: ...

class SpeechContinuousRecognitionResultGeneratedEventArgs(winsdk.system.Object):
    result: typing.Optional[SpeechRecognitionResult]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechContinuousRecognitionResultGeneratedEventArgs: ...

class SpeechContinuousRecognitionSession(winsdk.system.Object):
    auto_stop_silence_timeout: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechContinuousRecognitionSession: ...
    def cancel_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def pause_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def resume(self) -> None: ...
    @typing.overload
    def start_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def start_async(self, mode: SpeechContinuousRecognitionMode) -> winsdk.windows.foundation.IAsyncAction: ...
    def stop_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def add_completed(self, value: winsdk.windows.foundation.TypedEventHandler[SpeechContinuousRecognitionSession, SpeechContinuousRecognitionCompletedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_completed(self, value: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_result_generated(self, value: winsdk.windows.foundation.TypedEventHandler[SpeechContinuousRecognitionSession, SpeechContinuousRecognitionResultGeneratedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_result_generated(self, value: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class SpeechRecognitionCompilationResult(winsdk.system.Object):
    status: SpeechRecognitionResultStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechRecognitionCompilationResult: ...

class SpeechRecognitionGrammarFileConstraint(winsdk.system.Object):
    tag: str
    probability: SpeechRecognitionConstraintProbability
    is_enabled: winsdk.system.Boolean
    type: SpeechRecognitionConstraintType
    grammar_file: typing.Optional[winsdk.windows.storage.StorageFile]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechRecognitionGrammarFileConstraint: ...
    @typing.overload
    def __new__(cls: typing.Type[SpeechRecognitionGrammarFileConstraint], file: typing.Optional[winsdk.windows.storage.StorageFile]) -> SpeechRecognitionGrammarFileConstraint:...
    @typing.overload
    def __new__(cls: typing.Type[SpeechRecognitionGrammarFileConstraint], file: typing.Optional[winsdk.windows.storage.StorageFile], tag: str) -> SpeechRecognitionGrammarFileConstraint:...

class SpeechRecognitionHypothesis(winsdk.system.Object):
    text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechRecognitionHypothesis: ...

class SpeechRecognitionHypothesisGeneratedEventArgs(winsdk.system.Object):
    hypothesis: typing.Optional[SpeechRecognitionHypothesis]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechRecognitionHypothesisGeneratedEventArgs: ...

class SpeechRecognitionListConstraint(winsdk.system.Object):
    tag: str
    probability: SpeechRecognitionConstraintProbability
    is_enabled: winsdk.system.Boolean
    type: SpeechRecognitionConstraintType
    commands: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechRecognitionListConstraint: ...
    @typing.overload
    def __new__(cls: typing.Type[SpeechRecognitionListConstraint], commands: typing.Iterable[str]) -> SpeechRecognitionListConstraint:...
    @typing.overload
    def __new__(cls: typing.Type[SpeechRecognitionListConstraint], commands: typing.Iterable[str], tag: str) -> SpeechRecognitionListConstraint:...

class SpeechRecognitionQualityDegradingEventArgs(winsdk.system.Object):
    problem: SpeechRecognitionAudioProblem
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechRecognitionQualityDegradingEventArgs: ...

class SpeechRecognitionResult(winsdk.system.Object):
    confidence: SpeechRecognitionConfidence
    constraint: typing.Optional[ISpeechRecognitionConstraint]
    raw_confidence: winsdk.system.Double
    rule_path: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    semantic_interpretation: typing.Optional[SpeechRecognitionSemanticInterpretation]
    status: SpeechRecognitionResultStatus
    text: str
    phrase_duration: datetime.timedelta
    phrase_start_time: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechRecognitionResult: ...
    def get_alternates(self, max_alternates: winsdk.system.UInt32) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[SpeechRecognitionResult]]: ...

class SpeechRecognitionSemanticInterpretation(winsdk.system.Object):
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.windows.foundation.collections.IVectorView[str]]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechRecognitionSemanticInterpretation: ...

class SpeechRecognitionTopicConstraint(winsdk.system.Object):
    tag: str
    probability: SpeechRecognitionConstraintProbability
    is_enabled: winsdk.system.Boolean
    type: SpeechRecognitionConstraintType
    scenario: SpeechRecognitionScenario
    topic_hint: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechRecognitionTopicConstraint: ...
    @typing.overload
    def __new__(cls: typing.Type[SpeechRecognitionTopicConstraint], scenario: SpeechRecognitionScenario, topic_hint: str) -> SpeechRecognitionTopicConstraint:...
    @typing.overload
    def __new__(cls: typing.Type[SpeechRecognitionTopicConstraint], scenario: SpeechRecognitionScenario, topic_hint: str, tag: str) -> SpeechRecognitionTopicConstraint:...

class SpeechRecognitionVoiceCommandDefinitionConstraint(winsdk.system.Object):
    tag: str
    probability: SpeechRecognitionConstraintProbability
    is_enabled: winsdk.system.Boolean
    type: SpeechRecognitionConstraintType
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechRecognitionVoiceCommandDefinitionConstraint: ...

class SpeechRecognizer(winsdk.system.Object):
    constraints: typing.Optional[winsdk.windows.foundation.collections.IVector[ISpeechRecognitionConstraint]]
    current_language: typing.Optional[winsdk.windows.globalization.Language]
    timeouts: typing.Optional[SpeechRecognizerTimeouts]
    u_i_options: typing.Optional[SpeechRecognizerUIOptions]
    continuous_recognition_session: typing.Optional[SpeechContinuousRecognitionSession]
    state: SpeechRecognizerState
    supported_grammar_languages: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.globalization.Language]]]
    supported_topic_languages: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.globalization.Language]]]
    system_speech_language: typing.ClassVar[typing.Optional[winsdk.windows.globalization.Language]]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechRecognizer: ...
    @typing.overload
    def __new__(cls: typing.Type[SpeechRecognizer], language: typing.Optional[winsdk.windows.globalization.Language]) -> SpeechRecognizer:...
    @typing.overload
    def __new__(cls: typing.Type[SpeechRecognizer]) -> SpeechRecognizer:...
    def close(self) -> None: ...
    def compile_constraints_async(self) -> winsdk.windows.foundation.IAsyncOperation[SpeechRecognitionCompilationResult]: ...
    def recognize_async(self) -> winsdk.windows.foundation.IAsyncOperation[SpeechRecognitionResult]: ...
    def recognize_with_u_i_async(self) -> winsdk.windows.foundation.IAsyncOperation[SpeechRecognitionResult]: ...
    def stop_recognition_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def try_set_system_speech_language_async(speech_language: typing.Optional[winsdk.windows.globalization.Language]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def add_recognition_quality_degrading(self, speech_recognition_quality_degrading_handler: winsdk.windows.foundation.TypedEventHandler[SpeechRecognizer, SpeechRecognitionQualityDegradingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_recognition_quality_degrading(self, cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_state_changed(self, state_changed_handler: winsdk.windows.foundation.TypedEventHandler[SpeechRecognizer, SpeechRecognizerStateChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_state_changed(self, cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_hypothesis_generated(self, value: winsdk.windows.foundation.TypedEventHandler[SpeechRecognizer, SpeechRecognitionHypothesisGeneratedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_hypothesis_generated(self, value: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class SpeechRecognizerStateChangedEventArgs(winsdk.system.Object):
    state: SpeechRecognizerState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechRecognizerStateChangedEventArgs: ...

class SpeechRecognizerTimeouts(winsdk.system.Object):
    initial_silence_timeout: datetime.timedelta
    end_silence_timeout: datetime.timedelta
    babble_timeout: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechRecognizerTimeouts: ...

class SpeechRecognizerUIOptions(winsdk.system.Object):
    show_confirmation: winsdk.system.Boolean
    is_read_back_enabled: winsdk.system.Boolean
    example_text: str
    audible_prompt: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeechRecognizerUIOptions: ...

class VoiceCommandManager(winsdk.system.Object):
    installed_command_sets: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IMapView[str, VoiceCommandSet]]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VoiceCommandManager: ...
    @staticmethod
    def install_command_sets_from_storage_file_async(file: typing.Optional[winsdk.windows.storage.StorageFile]) -> winsdk.windows.foundation.IAsyncAction: ...

class VoiceCommandSet(winsdk.system.Object):
    language: str
    name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VoiceCommandSet: ...
    def set_phrase_list_async(self, phrase_list_name: str, phrase_list: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncAction: ...

class ISpeechRecognitionConstraint(winsdk.system.Object):
    is_enabled: winsdk.system.Boolean
    probability: SpeechRecognitionConstraintProbability
    tag: str
    type: SpeechRecognitionConstraintType
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ISpeechRecognitionConstraint: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Networking.BackgroundTransfer")

try:
    import winsdk.windows.applicationmodel.background
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.security.credentials
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.ui.notifications
except ImportError:
    pass

try:
    import winsdk.windows.web
except ImportError:
    pass

class BackgroundTransferBehavior(enum.IntEnum):
    PARALLEL = 0
    SERIALIZED = 1

class BackgroundTransferCostPolicy(enum.IntEnum):
    DEFAULT = 0
    UNRESTRICTED_ONLY = 1
    ALWAYS = 2

class BackgroundTransferPriority(enum.IntEnum):
    DEFAULT = 0
    HIGH = 1
    LOW = 2

class BackgroundTransferStatus(enum.IntEnum):
    IDLE = 0
    RUNNING = 1
    PAUSED_BY_APPLICATION = 2
    PAUSED_COSTED_NETWORK = 3
    PAUSED_NO_NETWORK = 4
    COMPLETED = 5
    CANCELED = 6
    ERROR = 7
    PAUSED_RECOVERABLE_WEB_ERROR_STATUS = 8
    PAUSED_SYSTEM_POLICY = 32

_ns_module._register_BackgroundTransferBehavior(BackgroundTransferBehavior)
_ns_module._register_BackgroundTransferCostPolicy(BackgroundTransferCostPolicy)
_ns_module._register_BackgroundTransferPriority(BackgroundTransferPriority)
_ns_module._register_BackgroundTransferStatus(BackgroundTransferStatus)

BackgroundDownloadProgress = _ns_module.BackgroundDownloadProgress
BackgroundTransferFileRange = _ns_module.BackgroundTransferFileRange
BackgroundUploadProgress = _ns_module.BackgroundUploadProgress
BackgroundDownloader = _ns_module.BackgroundDownloader
BackgroundTransferCompletionGroup = _ns_module.BackgroundTransferCompletionGroup
BackgroundTransferCompletionGroupTriggerDetails = _ns_module.BackgroundTransferCompletionGroupTriggerDetails
BackgroundTransferContentPart = _ns_module.BackgroundTransferContentPart
BackgroundTransferError = _ns_module.BackgroundTransferError
BackgroundTransferGroup = _ns_module.BackgroundTransferGroup
BackgroundTransferRangesDownloadedEventArgs = _ns_module.BackgroundTransferRangesDownloadedEventArgs
BackgroundUploader = _ns_module.BackgroundUploader
ContentPrefetcher = _ns_module.ContentPrefetcher
DownloadOperation = _ns_module.DownloadOperation
ResponseInformation = _ns_module.ResponseInformation
UnconstrainedTransferRequestResult = _ns_module.UnconstrainedTransferRequestResult
UploadOperation = _ns_module.UploadOperation
IBackgroundTransferBase = _ns_module.IBackgroundTransferBase
IBackgroundTransferContentPartFactory = _ns_module.IBackgroundTransferContentPartFactory
IBackgroundTransferOperation = _ns_module.IBackgroundTransferOperation
IBackgroundTransferOperationPriority = _ns_module.IBackgroundTransferOperationPriority



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.AI.MachineLearning")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.graphics
except ImportError:
    pass

try:
    import winsdk.windows.graphics.directx.direct3d11
except ImportError:
    pass

try:
    import winsdk.windows.graphics.imaging
except ImportError:
    pass

try:
    import winsdk.windows.media
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class LearningModelDeviceKind(enum.IntEnum):
    DEFAULT = 0
    CPU = 1
    DIRECT_X = 2
    DIRECT_X_HIGH_PERFORMANCE = 3
    DIRECT_X_MIN_POWER = 4

class LearningModelFeatureKind(enum.IntEnum):
    TENSOR = 0
    SEQUENCE = 1
    MAP = 2
    IMAGE = 3

class LearningModelPixelRange(enum.IntEnum):
    ZERO_TO255 = 0
    ZERO_TO_ONE = 1
    MINUS_ONE_TO_ONE = 2

class TensorKind(enum.IntEnum):
    UNDEFINED = 0
    FLOAT = 1
    UINT8 = 2
    INT8 = 3
    UINT16 = 4
    INT16 = 5
    INT32 = 6
    INT64 = 7
    STRING = 8
    BOOLEAN = 9
    FLOAT16 = 10
    DOUBLE = 11
    UINT32 = 12
    UINT64 = 13
    COMPLEX64 = 14
    COMPLEX128 = 15

_ns_module._register_LearningModelDeviceKind(LearningModelDeviceKind)
_ns_module._register_LearningModelFeatureKind(LearningModelFeatureKind)
_ns_module._register_LearningModelPixelRange(LearningModelPixelRange)
_ns_module._register_TensorKind(TensorKind)

ImageFeatureDescriptor = _ns_module.ImageFeatureDescriptor
ImageFeatureValue = _ns_module.ImageFeatureValue
LearningModel = _ns_module.LearningModel
LearningModelBinding = _ns_module.LearningModelBinding
LearningModelDevice = _ns_module.LearningModelDevice
LearningModelEvaluationResult = _ns_module.LearningModelEvaluationResult
LearningModelSession = _ns_module.LearningModelSession
LearningModelSessionOptions = _ns_module.LearningModelSessionOptions
MapFeatureDescriptor = _ns_module.MapFeatureDescriptor
SequenceFeatureDescriptor = _ns_module.SequenceFeatureDescriptor
TensorBoolean = _ns_module.TensorBoolean
TensorDouble = _ns_module.TensorDouble
TensorFeatureDescriptor = _ns_module.TensorFeatureDescriptor
TensorFloat = _ns_module.TensorFloat
TensorFloat16Bit = _ns_module.TensorFloat16Bit
TensorInt16Bit = _ns_module.TensorInt16Bit
TensorInt32Bit = _ns_module.TensorInt32Bit
TensorInt64Bit = _ns_module.TensorInt64Bit
TensorInt8Bit = _ns_module.TensorInt8Bit
TensorString = _ns_module.TensorString
TensorUInt16Bit = _ns_module.TensorUInt16Bit
TensorUInt32Bit = _ns_module.TensorUInt32Bit
TensorUInt64Bit = _ns_module.TensorUInt64Bit
TensorUInt8Bit = _ns_module.TensorUInt8Bit
ILearningModelFeatureDescriptor = _ns_module.ILearningModelFeatureDescriptor
ILearningModelFeatureValue = _ns_module.ILearningModelFeatureValue
ILearningModelOperatorProvider = _ns_module.ILearningModelOperatorProvider
ITensor = _ns_module.ITensor



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage.streams

class ContactChangeType(enum.IntEnum):
    CREATED = 0
    MODIFIED = 1
    DELETED = 2

class ContactQueryResultOrdering(enum.IntEnum):
    SYSTEM_DEFAULT = 0
    GIVEN_NAME_FAMILY_NAME = 1
    FAMILY_NAME_GIVEN_NAME = 2

class ContactStoreApplicationAccessMode(enum.IntEnum):
    LIMITED_READ_ONLY = 0
    READ_ONLY = 1

class ContactStoreSystemAccessMode(enum.IntEnum):
    READ_ONLY = 0
    READ_WRITE = 1

class VCardFormat(enum.IntEnum):
    VERSION2_1 = 0
    VERSION3 = 1

Self = typing.TypeVar('Self')

class ContactAddress(winsdk.system.Object):
    street_address: str
    region: str
    postal_code: str
    locality: str
    country: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactAddress: ...
    def __new__(cls: typing.Type[ContactAddress]) -> ContactAddress:...

class ContactChangeRecord(winsdk.system.Object):
    change_type: ContactChangeType
    id: str
    remote_id: str
    revision_number: winsdk.system.UInt64
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactChangeRecord: ...

class ContactInformation(winsdk.system.Object):
    honorific_suffix: str
    honorific_prefix: str
    given_name: str
    family_name: str
    display_name: str
    display_picture: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactInformation: ...
    def __new__(cls: typing.Type[ContactInformation]) -> ContactInformation:...
    def get_display_picture_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStream]: ...
    def get_properties_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IMap[str, winsdk.system.Object]]: ...
    @staticmethod
    def parse_vcard_async(vcard: typing.Optional[winsdk.windows.storage.streams.IInputStream]) -> winsdk.windows.foundation.IAsyncOperation[ContactInformation]: ...
    def set_display_picture_async(self, stream: typing.Optional[winsdk.windows.storage.streams.IInputStream]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def to_vcard_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStream]: ...
    @typing.overload
    def to_vcard_async(self, format: VCardFormat) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStream]: ...

class ContactQueryOptions(winsdk.system.Object):
    order_by: ContactQueryResultOrdering
    desired_fields: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactQueryOptions: ...
    def __new__(cls: typing.Type[ContactQueryOptions]) -> ContactQueryOptions:...

class ContactQueryResult(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactQueryResult: ...
    def get_contact_count_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.UInt32]: ...
    @typing.overload
    def get_contacts_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[StoredContact]]: ...
    @typing.overload
    def get_contacts_async(self, start_index: winsdk.system.UInt32, max_number_of_items: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[StoredContact]]: ...
    def get_current_query_options(self) -> typing.Optional[ContactQueryOptions]: ...

class ContactStore(winsdk.system.Object):
    revision_number: winsdk.system.UInt64
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactStore: ...
    @typing.overload
    def create_contact_query(self) -> typing.Optional[ContactQueryResult]: ...
    @typing.overload
    def create_contact_query(self, options: typing.Optional[ContactQueryOptions]) -> typing.Optional[ContactQueryResult]: ...
    def create_me_contact_async(self, id: str) -> winsdk.windows.foundation.IAsyncOperation[StoredContact]: ...
    @typing.overload
    @staticmethod
    def create_or_open_async() -> winsdk.windows.foundation.IAsyncOperation[ContactStore]: ...
    @typing.overload
    @staticmethod
    def create_or_open_async(access: ContactStoreSystemAccessMode, sharing: ContactStoreApplicationAccessMode) -> winsdk.windows.foundation.IAsyncOperation[ContactStore]: ...
    def delete_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def delete_contact_async(self, id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    def find_contact_by_id_async(self, id: str) -> winsdk.windows.foundation.IAsyncOperation[StoredContact]: ...
    def find_contact_by_remote_id_async(self, id: str) -> winsdk.windows.foundation.IAsyncOperation[StoredContact]: ...
    def get_changes_async(self, base_revision_number: winsdk.system.UInt64) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[ContactChangeRecord]]: ...
    def load_extended_properties_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IMap[str, winsdk.system.Object]]: ...
    def save_extended_properties_async(self, data: winsdk.windows.foundation.collections.IMapView[str, winsdk.system.Object]) -> winsdk.windows.foundation.IAsyncAction: ...

class KnownContactProperties(winsdk.system.Object):
    additional_name: typing.ClassVar[str]
    address: typing.ClassVar[str]
    alternate_mobile_telephone: typing.ClassVar[str]
    alternate_telephone: typing.ClassVar[str]
    alternate_work_telephone: typing.ClassVar[str]
    anniversary: typing.ClassVar[str]
    birthdate: typing.ClassVar[str]
    children: typing.ClassVar[str]
    company_name: typing.ClassVar[str]
    company_telephone: typing.ClassVar[str]
    display_name: typing.ClassVar[str]
    email: typing.ClassVar[str]
    family_name: typing.ClassVar[str]
    given_name: typing.ClassVar[str]
    home_fax: typing.ClassVar[str]
    honorific_prefix: typing.ClassVar[str]
    honorific_suffix: typing.ClassVar[str]
    job_title: typing.ClassVar[str]
    manager: typing.ClassVar[str]
    mobile_telephone: typing.ClassVar[str]
    nickname: typing.ClassVar[str]
    notes: typing.ClassVar[str]
    office_location: typing.ClassVar[str]
    other_address: typing.ClassVar[str]
    other_email: typing.ClassVar[str]
    significant_other: typing.ClassVar[str]
    telephone: typing.ClassVar[str]
    url: typing.ClassVar[str]
    work_address: typing.ClassVar[str]
    work_email: typing.ClassVar[str]
    work_fax: typing.ClassVar[str]
    work_telephone: typing.ClassVar[str]
    yomi_company_name: typing.ClassVar[str]
    yomi_family_name: typing.ClassVar[str]
    yomi_given_name: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> KnownContactProperties: ...

class StoredContact(winsdk.system.Object):
    honorific_suffix: str
    honorific_prefix: str
    given_name: str
    family_name: str
    display_name: str
    display_picture: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    display_picture_date: datetime.datetime
    remote_id: str
    id: str
    store: typing.Optional[ContactStore]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoredContact: ...
    @typing.overload
    def __new__(cls: typing.Type[StoredContact], store: typing.Optional[ContactStore]) -> StoredContact:...
    @typing.overload
    def __new__(cls: typing.Type[StoredContact], store: typing.Optional[ContactStore], contact: typing.Optional[ContactInformation]) -> StoredContact:...
    def get_display_picture_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStream]: ...
    def get_extended_properties_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IMap[str, winsdk.system.Object]]: ...
    def get_properties_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IMap[str, winsdk.system.Object]]: ...
    def replace_existing_contact_async(self, id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    def save_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def set_display_picture_async(self, stream: typing.Optional[winsdk.windows.storage.streams.IInputStream]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def to_vcard_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStream]: ...
    @typing.overload
    def to_vcard_async(self, format: VCardFormat) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStream]: ...

class IContactInformation(winsdk.system.Object):
    display_name: str
    display_picture: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    family_name: str
    given_name: str
    honorific_prefix: str
    honorific_suffix: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IContactInformation: ...
    def get_display_picture_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStream]: ...
    def get_properties_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IMap[str, winsdk.system.Object]]: ...
    def set_display_picture_async(self, stream: typing.Optional[winsdk.windows.storage.streams.IInputStream]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def to_vcard_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStream]: ...
    @typing.overload
    def to_vcard_async(self, format: VCardFormat) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStream]: ...

class IContactInformation2(winsdk.system.Object):
    display_picture_date: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IContactInformation2: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation

class WorkItemOptions(enum.IntFlag):
    NONE = 0
    TIME_SLICED = 0x1

class WorkItemPriority(enum.IntEnum):
    LOW = -1
    NORMAL = 0
    HIGH = 1

Self = typing.TypeVar('Self')

class ThreadPool(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ThreadPool: ...
    @typing.overload
    @staticmethod
    def run_async(handler: typing.Optional[WorkItemHandler]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def run_async(handler: typing.Optional[WorkItemHandler], priority: WorkItemPriority) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def run_async(handler: typing.Optional[WorkItemHandler], priority: WorkItemPriority, options: WorkItemOptions) -> winsdk.windows.foundation.IAsyncAction: ...

class ThreadPoolTimer(winsdk.system.Object):
    delay: datetime.timedelta
    period: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ThreadPoolTimer: ...
    def cancel(self) -> None: ...
    @typing.overload
    @staticmethod
    def create_periodic_timer(handler: typing.Optional[TimerElapsedHandler], period: datetime.timedelta) -> typing.Optional[ThreadPoolTimer]: ...
    @typing.overload
    @staticmethod
    def create_periodic_timer(handler: typing.Optional[TimerElapsedHandler], period: datetime.timedelta, destroyed: typing.Optional[TimerDestroyedHandler]) -> typing.Optional[ThreadPoolTimer]: ...
    @typing.overload
    @staticmethod
    def create_timer(handler: typing.Optional[TimerElapsedHandler], delay: datetime.timedelta) -> typing.Optional[ThreadPoolTimer]: ...
    @typing.overload
    @staticmethod
    def create_timer(handler: typing.Optional[TimerElapsedHandler], delay: datetime.timedelta, destroyed: typing.Optional[TimerDestroyedHandler]) -> typing.Optional[ThreadPoolTimer]: ...

TimerDestroyedHandler = typing.Callable[[typing.Optional[ThreadPoolTimer]], None]

TimerElapsedHandler = typing.Callable[[typing.Optional[ThreadPoolTimer]], None]

WorkItemHandler = typing.Callable[[winsdk.windows.foundation.IAsyncAction], None]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.devices.spi.provider
import winsdk.windows.foundation
import winsdk.windows.foundation.collections

class SpiMode(enum.IntEnum):
    MODE0 = 0
    MODE1 = 1
    MODE2 = 2
    MODE3 = 3

class SpiSharingMode(enum.IntEnum):
    EXCLUSIVE = 0
    SHARED = 1

Self = typing.TypeVar('Self')

class SpiBusInfo(winsdk.system.Object):
    chip_select_line_count: winsdk.system.Int32
    max_clock_frequency: winsdk.system.Int32
    min_clock_frequency: winsdk.system.Int32
    supported_data_bit_lengths: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int32]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpiBusInfo: ...

class SpiConnectionSettings(winsdk.system.Object):
    sharing_mode: SpiSharingMode
    mode: SpiMode
    data_bit_length: winsdk.system.Int32
    clock_frequency: winsdk.system.Int32
    chip_select_line: winsdk.system.Int32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpiConnectionSettings: ...
    def __new__(cls: typing.Type[SpiConnectionSettings], chip_select_line: winsdk.system.Int32) -> SpiConnectionSettings:...

class SpiController(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpiController: ...
    @staticmethod
    def get_controllers_async(provider: typing.Optional[winsdk.windows.devices.spi.provider.ISpiProvider]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[SpiController]]: ...
    @staticmethod
    def get_default_async() -> winsdk.windows.foundation.IAsyncOperation[SpiController]: ...
    def get_device(self, settings: typing.Optional[SpiConnectionSettings]) -> typing.Optional[SpiDevice]: ...

class SpiDevice(winsdk.system.Object):
    connection_settings: typing.Optional[SpiConnectionSettings]
    device_id: str
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpiDevice: ...
    def close(self) -> None: ...
    @staticmethod
    def from_id_async(bus_id: str, settings: typing.Optional[SpiConnectionSettings]) -> winsdk.windows.foundation.IAsyncOperation[SpiDevice]: ...
    @staticmethod
    def get_bus_info(bus_id: str) -> typing.Optional[SpiBusInfo]: ...
    @typing.overload
    @staticmethod
    def get_device_selector() -> str: ...
    @typing.overload
    @staticmethod
    def get_device_selector(friendly_name: str) -> str: ...
    def read(self, buffer: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def transfer_full_duplex(self, write_buffer: winsdk.system.Array[winsdk.system.UInt8], read_buffer: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def transfer_sequential(self, write_buffer: winsdk.system.Array[winsdk.system.UInt8], read_buffer: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def write(self, buffer: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...

class ISpiDeviceStatics(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ISpiDeviceStatics: ...
    def from_id_async(self, bus_id: str, settings: typing.Optional[SpiConnectionSettings]) -> winsdk.windows.foundation.IAsyncOperation[SpiDevice]: ...
    def get_bus_info(self, bus_id: str) -> typing.Optional[SpiBusInfo]: ...
    @typing.overload
    def get_device_selector(self) -> str: ...
    @typing.overload
    def get_device_selector(self, friendly_name: str) -> str: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.storage

Self = typing.TypeVar('Self')

class PhoneCallOrigin(winsdk.system.Object):
    location: str
    category_description: str
    category: str
    display_name: str
    display_picture: typing.Optional[winsdk.windows.storage.StorageFile]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PhoneCallOrigin: ...
    def __new__(cls: typing.Type[PhoneCallOrigin]) -> PhoneCallOrigin:...

class PhoneCallOriginManager(winsdk.system.Object):
    is_current_app_active_call_origin_app: typing.ClassVar[winsdk.system.Boolean]
    is_supported: typing.ClassVar[winsdk.system.Boolean]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PhoneCallOriginManager: ...
    @staticmethod
    def request_set_as_active_call_origin_app_async() -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    @staticmethod
    def set_call_origin(request_id: winsdk.system.Guid, call_origin: typing.Optional[PhoneCallOrigin]) -> None: ...
    @staticmethod
    def show_phone_call_origin_settings_u_i() -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.background
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.security.credentials
import winsdk.windows.storage.streams
import winsdk.windows.ui
import winsdk.windows.ui.popups

class DeviceAccessStatus(enum.IntEnum):
    UNSPECIFIED = 0
    ALLOWED = 1
    DENIED_BY_USER = 2
    DENIED_BY_SYSTEM = 3

class DeviceClass(enum.IntEnum):
    ALL = 0
    AUDIO_CAPTURE = 1
    AUDIO_RENDER = 2
    PORTABLE_STORAGE_DEVICE = 3
    VIDEO_CAPTURE = 4
    IMAGE_SCANNER = 5
    LOCATION = 6

class DeviceInformationKind(enum.IntEnum):
    UNKNOWN = 0
    DEVICE_INTERFACE = 1
    DEVICE_CONTAINER = 2
    DEVICE = 3
    DEVICE_INTERFACE_CLASS = 4
    ASSOCIATION_ENDPOINT = 5
    ASSOCIATION_ENDPOINT_CONTAINER = 6
    ASSOCIATION_ENDPOINT_SERVICE = 7
    DEVICE_PANEL = 8

class DevicePairingKinds(enum.IntFlag):
    NONE = 0
    CONFIRM_ONLY = 0x1
    DISPLAY_PIN = 0x2
    PROVIDE_PIN = 0x4
    CONFIRM_PIN_MATCH = 0x8
    PROVIDE_PASSWORD_CREDENTIAL = 0x10

class DevicePairingProtectionLevel(enum.IntEnum):
    DEFAULT = 0
    NONE = 1
    ENCRYPTION = 2
    ENCRYPTION_AND_AUTHENTICATION = 3

class DevicePairingResultStatus(enum.IntEnum):
    PAIRED = 0
    NOT_READY_TO_PAIR = 1
    NOT_PAIRED = 2
    ALREADY_PAIRED = 3
    CONNECTION_REJECTED = 4
    TOO_MANY_CONNECTIONS = 5
    HARDWARE_FAILURE = 6
    AUTHENTICATION_TIMEOUT = 7
    AUTHENTICATION_NOT_ALLOWED = 8
    AUTHENTICATION_FAILURE = 9
    NO_SUPPORTED_PROFILES = 10
    PROTECTION_LEVEL_COULD_NOT_BE_MET = 11
    ACCESS_DENIED = 12
    INVALID_CEREMONY_DATA = 13
    PAIRING_CANCELED = 14
    OPERATION_ALREADY_IN_PROGRESS = 15
    REQUIRED_HANDLER_NOT_REGISTERED = 16
    REJECTED_BY_HANDLER = 17
    REMOTE_DEVICE_HAS_ASSOCIATION = 18
    FAILED = 19

class DevicePickerDisplayStatusOptions(enum.IntFlag):
    NONE = 0
    SHOW_PROGRESS = 0x1
    SHOW_DISCONNECT_BUTTON = 0x2
    SHOW_RETRY_BUTTON = 0x4

class DeviceUnpairingResultStatus(enum.IntEnum):
    UNPAIRED = 0
    ALREADY_UNPAIRED = 1
    OPERATION_ALREADY_IN_PROGRESS = 2
    ACCESS_DENIED = 3
    FAILED = 4

class DeviceWatcherEventKind(enum.IntEnum):
    ADD = 0
    UPDATE = 1
    REMOVE = 2

class DeviceWatcherStatus(enum.IntEnum):
    CREATED = 0
    STARTED = 1
    ENUMERATION_COMPLETED = 2
    STOPPING = 3
    STOPPED = 4
    ABORTED = 5

class Panel(enum.IntEnum):
    UNKNOWN = 0
    FRONT = 1
    BACK = 2
    TOP = 3
    BOTTOM = 4
    LEFT = 5
    RIGHT = 6

Self = typing.TypeVar('Self')

class DeviceAccessChangedEventArgs(winsdk.system.Object):
    status: DeviceAccessStatus
    id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceAccessChangedEventArgs: ...

class DeviceAccessInformation(winsdk.system.Object):
    current_status: DeviceAccessStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceAccessInformation: ...
    @staticmethod
    def create_from_device_class(device_class: DeviceClass) -> typing.Optional[DeviceAccessInformation]: ...
    @staticmethod
    def create_from_device_class_id(device_class_id: winsdk.system.Guid) -> typing.Optional[DeviceAccessInformation]: ...
    @staticmethod
    def create_from_id(device_id: str) -> typing.Optional[DeviceAccessInformation]: ...
    def add_access_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[DeviceAccessInformation, DeviceAccessChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_access_changed(self, cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class DeviceConnectionChangeTriggerDetails(winsdk.system.Object):
    device_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceConnectionChangeTriggerDetails: ...

class DeviceDisconnectButtonClickedEventArgs(winsdk.system.Object):
    device: typing.Optional[DeviceInformation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceDisconnectButtonClickedEventArgs: ...

class DeviceInformation(winsdk.system.Object):
    enclosure_location: typing.Optional[EnclosureLocation]
    id: str
    is_default: winsdk.system.Boolean
    is_enabled: winsdk.system.Boolean
    name: str
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.system.Object]]
    kind: DeviceInformationKind
    pairing: typing.Optional[DeviceInformationPairing]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceInformation: ...
    @typing.overload
    @staticmethod
    def create_from_id_async(device_id: str) -> winsdk.windows.foundation.IAsyncOperation[DeviceInformation]: ...
    @typing.overload
    @staticmethod
    def create_from_id_async(device_id: str, additional_properties: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[DeviceInformation]: ...
    @typing.overload
    @staticmethod
    def create_from_id_async(device_id: str, additional_properties: typing.Iterable[str], kind: DeviceInformationKind) -> winsdk.windows.foundation.IAsyncOperation[DeviceInformation]: ...
    @typing.overload
    @staticmethod
    def create_watcher() -> typing.Optional[DeviceWatcher]: ...
    @typing.overload
    @staticmethod
    def create_watcher(device_class: DeviceClass) -> typing.Optional[DeviceWatcher]: ...
    @typing.overload
    @staticmethod
    def create_watcher(aqs_filter: str, additional_properties: typing.Iterable[str]) -> typing.Optional[DeviceWatcher]: ...
    @typing.overload
    @staticmethod
    def create_watcher(aqs_filter: str, additional_properties: typing.Iterable[str], kind: DeviceInformationKind) -> typing.Optional[DeviceWatcher]: ...
    @typing.overload
    @staticmethod
    def find_all_async() -> winsdk.windows.foundation.IAsyncOperation[DeviceInformationCollection]: ...
    @typing.overload
    @staticmethod
    def find_all_async(device_class: DeviceClass) -> winsdk.windows.foundation.IAsyncOperation[DeviceInformationCollection]: ...
    @typing.overload
    @staticmethod
    def find_all_async(aqs_filter: str, additional_properties: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[DeviceInformationCollection]: ...
    @typing.overload
    @staticmethod
    def find_all_async(aqs_filter: str, additional_properties: typing.Iterable[str], kind: DeviceInformationKind) -> winsdk.windows.foundation.IAsyncOperation[DeviceInformationCollection]: ...
    @staticmethod
    def get_aqs_filter_from_device_class(device_class: DeviceClass) -> str: ...
    def get_glyph_thumbnail_async(self) -> winsdk.windows.foundation.IAsyncOperation[DeviceThumbnail]: ...
    def get_thumbnail_async(self) -> winsdk.windows.foundation.IAsyncOperation[DeviceThumbnail]: ...
    def update(self, update_info: typing.Optional[DeviceInformationUpdate]) -> None: ...

class DeviceInformationCollection(winsdk.system.Object, typing.Sequence[DeviceInformation]):
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    @typing.overload
    def __getitem__(self, index: int) -> DeviceInformation: ...
    @typing.overload
    def __getitem__(self, index: slice) -> winsdk.system.Array[DeviceInformation]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceInformationCollection: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[DeviceInformation]]: ...
    def get_at(self, index: winsdk.system.UInt32) -> typing.Optional[DeviceInformation]: ...
    def get_many(self, start_index: winsdk.system.UInt32, items: winsdk.system.Array[DeviceInformation]) -> winsdk.system.UInt32: ...
    def index_of(self, value: typing.Optional[DeviceInformation]) -> typing.Tuple[winsdk.system.Boolean, winsdk.system.UInt32]: ...

class DeviceInformationCustomPairing(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceInformationCustomPairing: ...
    @typing.overload
    def pair_async(self, pairing_kinds_supported: DevicePairingKinds) -> winsdk.windows.foundation.IAsyncOperation[DevicePairingResult]: ...
    @typing.overload
    def pair_async(self, pairing_kinds_supported: DevicePairingKinds, min_protection_level: DevicePairingProtectionLevel) -> winsdk.windows.foundation.IAsyncOperation[DevicePairingResult]: ...
    @typing.overload
    def pair_async(self, pairing_kinds_supported: DevicePairingKinds, min_protection_level: DevicePairingProtectionLevel, device_pairing_settings: typing.Optional[IDevicePairingSettings]) -> winsdk.windows.foundation.IAsyncOperation[DevicePairingResult]: ...
    def add_pairing_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[DeviceInformationCustomPairing, DevicePairingRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_pairing_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class DeviceInformationPairing(winsdk.system.Object):
    can_pair: winsdk.system.Boolean
    is_paired: winsdk.system.Boolean
    custom: typing.Optional[DeviceInformationCustomPairing]
    protection_level: DevicePairingProtectionLevel
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceInformationPairing: ...
    @typing.overload
    def pair_async(self) -> winsdk.windows.foundation.IAsyncOperation[DevicePairingResult]: ...
    @typing.overload
    def pair_async(self, min_protection_level: DevicePairingProtectionLevel) -> winsdk.windows.foundation.IAsyncOperation[DevicePairingResult]: ...
    @typing.overload
    def pair_async(self, min_protection_level: DevicePairingProtectionLevel, device_pairing_settings: typing.Optional[IDevicePairingSettings]) -> winsdk.windows.foundation.IAsyncOperation[DevicePairingResult]: ...
    @staticmethod
    def try_register_for_all_inbound_pairing_requests(pairing_kinds_supported: DevicePairingKinds) -> winsdk.system.Boolean: ...
    @staticmethod
    def try_register_for_all_inbound_pairing_requests_with_protection_level(pairing_kinds_supported: DevicePairingKinds, min_protection_level: DevicePairingProtectionLevel) -> winsdk.system.Boolean: ...
    def unpair_async(self) -> winsdk.windows.foundation.IAsyncOperation[DeviceUnpairingResult]: ...

class DeviceInformationUpdate(winsdk.system.Object):
    id: str
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.system.Object]]
    kind: DeviceInformationKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceInformationUpdate: ...

class DevicePairingRequestedEventArgs(winsdk.system.Object):
    device_information: typing.Optional[DeviceInformation]
    pairing_kind: DevicePairingKinds
    pin: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DevicePairingRequestedEventArgs: ...
    @typing.overload
    def accept(self) -> None: ...
    @typing.overload
    def accept(self, pin: str) -> None: ...
    def accept_with_password_credential(self, password_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]) -> None: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class DevicePairingResult(winsdk.system.Object):
    protection_level_used: DevicePairingProtectionLevel
    status: DevicePairingResultStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DevicePairingResult: ...

class DevicePicker(winsdk.system.Object):
    appearance: typing.Optional[DevicePickerAppearance]
    filter: typing.Optional[DevicePickerFilter]
    requested_properties: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DevicePicker: ...
    def __new__(cls: typing.Type[DevicePicker]) -> DevicePicker:...
    def hide(self) -> None: ...
    @typing.overload
    def pick_single_device_async(self, selection: winsdk.windows.foundation.Rect) -> winsdk.windows.foundation.IAsyncOperation[DeviceInformation]: ...
    @typing.overload
    def pick_single_device_async(self, selection: winsdk.windows.foundation.Rect, placement: winsdk.windows.ui.popups.Placement) -> winsdk.windows.foundation.IAsyncOperation[DeviceInformation]: ...
    def set_display_status(self, device: typing.Optional[DeviceInformation], status: str, options: DevicePickerDisplayStatusOptions) -> None: ...
    @typing.overload
    def show(self, selection: winsdk.windows.foundation.Rect) -> None: ...
    @typing.overload
    def show(self, selection: winsdk.windows.foundation.Rect, placement: winsdk.windows.ui.popups.Placement) -> None: ...
    def add_device_picker_dismissed(self, handler: winsdk.windows.foundation.TypedEventHandler[DevicePicker, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_device_picker_dismissed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_device_selected(self, handler: winsdk.windows.foundation.TypedEventHandler[DevicePicker, DeviceSelectedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_device_selected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_disconnect_button_clicked(self, handler: winsdk.windows.foundation.TypedEventHandler[DevicePicker, DeviceDisconnectButtonClickedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_disconnect_button_clicked(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class DevicePickerAppearance(winsdk.system.Object):
    title: str
    selected_foreground_color: winsdk.windows.ui.Color
    selected_background_color: winsdk.windows.ui.Color
    selected_accent_color: winsdk.windows.ui.Color
    foreground_color: winsdk.windows.ui.Color
    background_color: winsdk.windows.ui.Color
    accent_color: winsdk.windows.ui.Color
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DevicePickerAppearance: ...

class DevicePickerFilter(winsdk.system.Object):
    supported_device_classes: typing.Optional[winsdk.windows.foundation.collections.IVector[DeviceClass]]
    supported_device_selectors: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DevicePickerFilter: ...

class DeviceSelectedEventArgs(winsdk.system.Object):
    selected_device: typing.Optional[DeviceInformation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceSelectedEventArgs: ...

class DeviceThumbnail(winsdk.system.Object):
    content_type: str
    size: winsdk.system.UInt64
    can_read: winsdk.system.Boolean
    can_write: winsdk.system.Boolean
    position: winsdk.system.UInt64
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceThumbnail: ...
    def clone_stream(self) -> typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]: ...
    def close(self) -> None: ...
    def flush_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def get_input_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[winsdk.windows.storage.streams.IInputStream]: ...
    def get_output_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[winsdk.windows.storage.streams.IOutputStream]: ...
    def read_async(self, buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer], count: winsdk.system.UInt32, options: winsdk.windows.storage.streams.InputStreamOptions) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.windows.storage.streams.IBuffer, winsdk.system.UInt32]: ...
    def seek(self, position: winsdk.system.UInt64) -> None: ...
    def write_async(self, buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt32, winsdk.system.UInt32]: ...

class DeviceUnpairingResult(winsdk.system.Object):
    status: DeviceUnpairingResultStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceUnpairingResult: ...

class DeviceWatcher(winsdk.system.Object):
    status: DeviceWatcherStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceWatcher: ...
    def get_background_trigger(self, requested_event_kinds: typing.Iterable[DeviceWatcherEventKind]) -> typing.Optional[winsdk.windows.applicationmodel.background.DeviceWatcherTrigger]: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...
    def add_added(self, handler: winsdk.windows.foundation.TypedEventHandler[DeviceWatcher, DeviceInformation]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_added(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_enumeration_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[DeviceWatcher, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_enumeration_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_removed(self, handler: winsdk.windows.foundation.TypedEventHandler[DeviceWatcher, DeviceInformationUpdate]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_removed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_stopped(self, handler: winsdk.windows.foundation.TypedEventHandler[DeviceWatcher, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_stopped(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_updated(self, handler: winsdk.windows.foundation.TypedEventHandler[DeviceWatcher, DeviceInformationUpdate]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_updated(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class DeviceWatcherEvent(winsdk.system.Object):
    device_information: typing.Optional[DeviceInformation]
    device_information_update: typing.Optional[DeviceInformationUpdate]
    kind: DeviceWatcherEventKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceWatcherEvent: ...

class DeviceWatcherTriggerDetails(winsdk.system.Object):
    device_watcher_events: typing.Optional[winsdk.windows.foundation.collections.IVectorView[DeviceWatcherEvent]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceWatcherTriggerDetails: ...

class EnclosureLocation(winsdk.system.Object):
    in_dock: winsdk.system.Boolean
    in_lid: winsdk.system.Boolean
    panel: Panel
    rotation_angle_in_degrees_clockwise: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EnclosureLocation: ...

class IDevicePairingSettings(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IDevicePairingSettings: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Resources.Management")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class IndexedResourceType(enum.IntEnum):
    STRING = 0
    PATH = 1
    EMBEDDED_DATA = 2

_ns_module._register_IndexedResourceType(IndexedResourceType)

IndexedResourceCandidate = _ns_module.IndexedResourceCandidate
IndexedResourceQualifier = _ns_module.IndexedResourceQualifier
ResourceIndexer = _ns_module.ResourceIndexer



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Graphics.Capture")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.graphics
except ImportError:
    pass

try:
    import winsdk.windows.graphics.directx
except ImportError:
    pass

try:
    import winsdk.windows.graphics.directx.direct3d11
except ImportError:
    pass

try:
    import winsdk.windows.security.authorization.appcapabilityaccess
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

try:
    import winsdk.windows.ui.composition
except ImportError:
    pass

class GraphicsCaptureAccessKind(enum.IntEnum):
    BORDERLESS = 0
    PROGRAMMATIC = 1

_ns_module._register_GraphicsCaptureAccessKind(GraphicsCaptureAccessKind)

Direct3D11CaptureFrame = _ns_module.Direct3D11CaptureFrame
Direct3D11CaptureFramePool = _ns_module.Direct3D11CaptureFramePool
GraphicsCaptureAccess = _ns_module.GraphicsCaptureAccess
GraphicsCaptureItem = _ns_module.GraphicsCaptureItem
GraphicsCapturePicker = _ns_module.GraphicsCapturePicker
GraphicsCaptureSession = _ns_module.GraphicsCaptureSession



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.appservice
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.networking.sockets
import winsdk.windows.web.http

class DevicePortalConnectionClosedReason(enum.IntEnum):
    UNKNOWN = 0
    RESOURCE_LIMITS_EXCEEDED = 1
    PROTOCOL_ERROR = 2
    NOT_AUTHORIZED = 3
    USER_NOT_PRESENT = 4
    SERVICE_TERMINATED = 5

Self = typing.TypeVar('Self')

class DevicePortalConnection(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DevicePortalConnection: ...
    @staticmethod
    def get_for_app_service_connection(app_service_connection: typing.Optional[winsdk.windows.applicationmodel.appservice.AppServiceConnection]) -> typing.Optional[DevicePortalConnection]: ...
    @typing.overload
    def get_server_message_web_socket_for_request(self, request: typing.Optional[winsdk.windows.web.http.HttpRequestMessage]) -> typing.Optional[winsdk.windows.networking.sockets.ServerMessageWebSocket]: ...
    @typing.overload
    def get_server_message_web_socket_for_request(self, request: typing.Optional[winsdk.windows.web.http.HttpRequestMessage], message_type: winsdk.windows.networking.sockets.SocketMessageType, protocol: str) -> typing.Optional[winsdk.windows.networking.sockets.ServerMessageWebSocket]: ...
    @typing.overload
    def get_server_message_web_socket_for_request(self, request: typing.Optional[winsdk.windows.web.http.HttpRequestMessage], message_type: winsdk.windows.networking.sockets.SocketMessageType, protocol: str, outbound_buffer_size_in_bytes: winsdk.system.UInt32, max_message_size: winsdk.system.UInt32, receive_mode: winsdk.windows.networking.sockets.MessageWebSocketReceiveMode) -> typing.Optional[winsdk.windows.networking.sockets.ServerMessageWebSocket]: ...
    @typing.overload
    def get_server_stream_web_socket_for_request(self, request: typing.Optional[winsdk.windows.web.http.HttpRequestMessage]) -> typing.Optional[winsdk.windows.networking.sockets.ServerStreamWebSocket]: ...
    @typing.overload
    def get_server_stream_web_socket_for_request(self, request: typing.Optional[winsdk.windows.web.http.HttpRequestMessage], protocol: str, outbound_buffer_size_in_bytes: winsdk.system.UInt32, no_delay: winsdk.system.Boolean) -> typing.Optional[winsdk.windows.networking.sockets.ServerStreamWebSocket]: ...
    def add_closed(self, handler: winsdk.windows.foundation.TypedEventHandler[DevicePortalConnection, DevicePortalConnectionClosedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_closed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_request_received(self, handler: winsdk.windows.foundation.TypedEventHandler[DevicePortalConnection, DevicePortalConnectionRequestReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_request_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class DevicePortalConnectionClosedEventArgs(winsdk.system.Object):
    reason: DevicePortalConnectionClosedReason
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DevicePortalConnectionClosedEventArgs: ...

class DevicePortalConnectionRequestReceivedEventArgs(winsdk.system.Object):
    request_message: typing.Optional[winsdk.windows.web.http.HttpRequestMessage]
    response_message: typing.Optional[winsdk.windows.web.http.HttpResponseMessage]
    is_web_socket_upgrade_request: winsdk.system.Boolean
    web_socket_protocols_requested: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DevicePortalConnectionRequestReceivedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Globalization.PhoneNumberFormatting")

class PhoneNumberFormat(enum.IntEnum):
    E164 = 0
    INTERNATIONAL = 1
    NATIONAL = 2
    RFC3966 = 3

class PhoneNumberMatchResult(enum.IntEnum):
    NO_MATCH = 0
    SHORT_NATIONAL_SIGNIFICANT_NUMBER_MATCH = 1
    NATIONAL_SIGNIFICANT_NUMBER_MATCH = 2
    EXACT_MATCH = 3

class PhoneNumberParseResult(enum.IntEnum):
    VALID = 0
    NOT_A_NUMBER = 1
    INVALID_COUNTRY_CODE = 2
    TOO_SHORT = 3
    TOO_LONG = 4

class PredictedPhoneNumberKind(enum.IntEnum):
    FIXED_LINE = 0
    MOBILE = 1
    FIXED_LINE_OR_MOBILE = 2
    TOLL_FREE = 3
    PREMIUM_RATE = 4
    SHARED_COST = 5
    VOIP = 6
    PERSONAL_NUMBER = 7
    PAGER = 8
    UNIVERSAL_ACCOUNT_NUMBER = 9
    VOICEMAIL = 10
    UNKNOWN = 11

_ns_module._register_PhoneNumberFormat(PhoneNumberFormat)
_ns_module._register_PhoneNumberMatchResult(PhoneNumberMatchResult)
_ns_module._register_PhoneNumberParseResult(PhoneNumberParseResult)
_ns_module._register_PredictedPhoneNumberKind(PredictedPhoneNumberKind)

PhoneNumberFormatter = _ns_module.PhoneNumberFormatter
PhoneNumberInfo = _ns_module.PhoneNumberInfo



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Enumeration.Pnp")

try:
    import winsdk.windows.devices.enumeration
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class PnpObjectType(enum.IntEnum):
    UNKNOWN = 0
    DEVICE_INTERFACE = 1
    DEVICE_CONTAINER = 2
    DEVICE = 3
    DEVICE_INTERFACE_CLASS = 4
    ASSOCIATION_ENDPOINT = 5
    ASSOCIATION_ENDPOINT_CONTAINER = 6
    ASSOCIATION_ENDPOINT_SERVICE = 7
    DEVICE_PANEL = 8

_ns_module._register_PnpObjectType(PnpObjectType)

PnpObject = _ns_module.PnpObject
PnpObjectCollection = _ns_module.PnpObjectCollection
PnpObjectUpdate = _ns_module.PnpObjectUpdate
PnpObjectWatcher = _ns_module.PnpObjectWatcher



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Security.Authentication.Web.Provider")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.security.authentication.web
except ImportError:
    pass

try:
    import winsdk.windows.security.authentication.web.core
except ImportError:
    pass

try:
    import winsdk.windows.security.credentials
except ImportError:
    pass

try:
    import winsdk.windows.security.cryptography.core
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.web.http
except ImportError:
    pass

class WebAccountClientViewType(enum.IntEnum):
    ID_ONLY = 0
    ID_AND_PROPERTIES = 1

class WebAccountProviderOperationKind(enum.IntEnum):
    REQUEST_TOKEN = 0
    GET_TOKEN_SILENTLY = 1
    ADD_ACCOUNT = 2
    MANAGE_ACCOUNT = 3
    DELETE_ACCOUNT = 4
    RETRIEVE_COOKIES = 5
    SIGN_OUT_ACCOUNT = 6

class WebAccountScope(enum.IntEnum):
    PER_USER = 0
    PER_APPLICATION = 1

class WebAccountSelectionOptions(enum.IntFlag):
    DEFAULT = 0
    NEW = 0x1

_ns_module._register_WebAccountClientViewType(WebAccountClientViewType)
_ns_module._register_WebAccountProviderOperationKind(WebAccountProviderOperationKind)
_ns_module._register_WebAccountScope(WebAccountScope)
_ns_module._register_WebAccountSelectionOptions(WebAccountSelectionOptions)

WebAccountClientView = _ns_module.WebAccountClientView
WebAccountManager = _ns_module.WebAccountManager
WebAccountProviderAddAccountOperation = _ns_module.WebAccountProviderAddAccountOperation
WebAccountProviderDeleteAccountOperation = _ns_module.WebAccountProviderDeleteAccountOperation
WebAccountProviderGetTokenSilentOperation = _ns_module.WebAccountProviderGetTokenSilentOperation
WebAccountProviderManageAccountOperation = _ns_module.WebAccountProviderManageAccountOperation
WebAccountProviderRequestTokenOperation = _ns_module.WebAccountProviderRequestTokenOperation
WebAccountProviderRetrieveCookiesOperation = _ns_module.WebAccountProviderRetrieveCookiesOperation
WebAccountProviderSignOutAccountOperation = _ns_module.WebAccountProviderSignOutAccountOperation
WebAccountProviderTriggerDetails = _ns_module.WebAccountProviderTriggerDetails
WebProviderTokenRequest = _ns_module.WebProviderTokenRequest
WebProviderTokenResponse = _ns_module.WebProviderTokenResponse
IWebAccountProviderBaseReportOperation = _ns_module.IWebAccountProviderBaseReportOperation
IWebAccountProviderOperation = _ns_module.IWebAccountProviderOperation
IWebAccountProviderSilentReportOperation = _ns_module.IWebAccountProviderSilentReportOperation
IWebAccountProviderTokenObjects = _ns_module.IWebAccountProviderTokenObjects
IWebAccountProviderTokenObjects2 = _ns_module.IWebAccountProviderTokenObjects2
IWebAccountProviderTokenOperation = _ns_module.IWebAccountProviderTokenOperation
IWebAccountProviderUIReportOperation = _ns_module.IWebAccountProviderUIReportOperation



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation.collections

class AsyncStatus(enum.IntEnum):
    CANCELED = 2
    COMPLETED = 1
    ERROR = 3
    STARTED = 0

class PropertyType(enum.IntEnum):
    EMPTY = 0
    UINT8 = 1
    INT16 = 2
    UINT16 = 3
    INT32 = 4
    UINT32 = 5
    INT64 = 6
    UINT64 = 7
    SINGLE = 8
    DOUBLE = 9
    CHAR16 = 10
    BOOLEAN = 11
    STRING = 12
    INSPECTABLE = 13
    DATE_TIME = 14
    TIME_SPAN = 15
    GUID = 16
    POINT = 17
    SIZE = 18
    RECT = 19
    OTHER_TYPE = 20
    UINT8_ARRAY = 1025
    INT16_ARRAY = 1026
    UINT16_ARRAY = 1027
    INT32_ARRAY = 1028
    UINT32_ARRAY = 1029
    INT64_ARRAY = 1030
    UINT64_ARRAY = 1031
    SINGLE_ARRAY = 1032
    DOUBLE_ARRAY = 1033
    CHAR16_ARRAY = 1034
    BOOLEAN_ARRAY = 1035
    STRING_ARRAY = 1036
    INSPECTABLE_ARRAY = 1037
    DATE_TIME_ARRAY = 1038
    TIME_SPAN_ARRAY = 1039
    GUID_ARRAY = 1040
    POINT_ARRAY = 1041
    SIZE_ARRAY = 1042
    RECT_ARRAY = 1043
    OTHER_TYPE_ARRAY = 1044

Self = typing.TypeVar('Self')
T = typing.TypeVar('T')
TProgress = typing.TypeVar('TProgress')
TResult = typing.TypeVar('TResult')
TSender = typing.TypeVar('TSender')

class EventRegistrationToken:
    value: winsdk.system.Int64
    def __new__(cls: typing.Type[EventRegistrationToken], value: winsdk.system.Int64) -> EventRegistrationToken: ...

class HResult:
    value: winsdk.system.Int32
    def __new__(cls: typing.Type[HResult], value: winsdk.system.Int32) -> HResult: ...

class Point:
    x: winsdk.system.Single
    y: winsdk.system.Single
    def __new__(cls: typing.Type[Point], x: winsdk.system.Single, y: winsdk.system.Single) -> Point: ...

class Rect:
    x: winsdk.system.Single
    y: winsdk.system.Single
    width: winsdk.system.Single
    height: winsdk.system.Single
    def __new__(cls: typing.Type[Rect], x: winsdk.system.Single, y: winsdk.system.Single, width: winsdk.system.Single, height: winsdk.system.Single) -> Rect: ...

class Size:
    width: winsdk.system.Single
    height: winsdk.system.Single
    def __new__(cls: typing.Type[Size], width: winsdk.system.Single, height: winsdk.system.Single) -> Size: ...

class Deferral(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Deferral: ...
    def __new__(cls: typing.Type[Deferral], handler: typing.Optional[DeferralCompletedHandler]) -> Deferral:...
    def close(self) -> None: ...
    def complete(self) -> None: ...

class GuidHelper(winsdk.system.Object):
    empty: typing.ClassVar[winsdk.system.Guid]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GuidHelper: ...
    @staticmethod
    def create_new_guid() -> winsdk.system.Guid: ...
    @staticmethod
    def equals(target: winsdk.system.Guid, value: winsdk.system.Guid) -> winsdk.system.Boolean: ...

class MemoryBuffer(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MemoryBuffer: ...
    def __new__(cls: typing.Type[MemoryBuffer], capacity: winsdk.system.UInt32) -> MemoryBuffer:...
    def close(self) -> None: ...
    def create_reference(self) -> typing.Optional[IMemoryBufferReference]: ...

class PropertyValue(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PropertyValue: ...
    @staticmethod
    def create_boolean(value: winsdk.system.Boolean) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_boolean_array(value: winsdk.system.Array[winsdk.system.Boolean]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_char16(value: winsdk.system.Char16) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_char16_array(value: winsdk.system.Array[winsdk.system.Char16]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_date_time(value: datetime.datetime) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_date_time_array(value: winsdk.system.Array[datetime.datetime]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_double(value: winsdk.system.Double) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_double_array(value: winsdk.system.Array[winsdk.system.Double]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_empty() -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_guid(value: winsdk.system.Guid) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_guid_array(value: winsdk.system.Array[winsdk.system.Guid]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_inspectable(value: typing.Optional[winsdk.system.Object]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_inspectable_array(value: winsdk.system.Array[winsdk.system.Object]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_int16(value: winsdk.system.Int16) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_int16_array(value: winsdk.system.Array[winsdk.system.Int16]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_int32(value: winsdk.system.Int32) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_int32_array(value: winsdk.system.Array[winsdk.system.Int32]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_int64(value: winsdk.system.Int64) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_int64_array(value: winsdk.system.Array[winsdk.system.Int64]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_point(value: Point) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_point_array(value: winsdk.system.Array[Point]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_rect(value: Rect) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_rect_array(value: winsdk.system.Array[Rect]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_single(value: winsdk.system.Single) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_single_array(value: winsdk.system.Array[winsdk.system.Single]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_size(value: Size) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_size_array(value: winsdk.system.Array[Size]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_string(value: str) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_string_array(value: winsdk.system.Array[str]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_time_span(value: datetime.timedelta) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_time_span_array(value: winsdk.system.Array[datetime.timedelta]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_uint16(value: winsdk.system.UInt16) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_uint16_array(value: winsdk.system.Array[winsdk.system.UInt16]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_uint32(value: winsdk.system.UInt32) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_uint32_array(value: winsdk.system.Array[winsdk.system.UInt32]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_uint64(value: winsdk.system.UInt64) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_uint64_array(value: winsdk.system.Array[winsdk.system.UInt64]) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_uint8(value: winsdk.system.UInt8) -> typing.Optional[winsdk.system.Object]: ...
    @staticmethod
    def create_uint8_array(value: winsdk.system.Array[winsdk.system.UInt8]) -> typing.Optional[winsdk.system.Object]: ...

class Uri(winsdk.system.Object):
    absolute_uri: str
    display_uri: str
    domain: str
    extension: str
    fragment: str
    host: str
    password: str
    path: str
    port: winsdk.system.Int32
    query: str
    query_parsed: typing.Optional[WwwFormUrlDecoder]
    raw_uri: str
    scheme_name: str
    suspicious: winsdk.system.Boolean
    user_name: str
    absolute_canonical_uri: str
    display_iri: str
    def __str__(self) -> str: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Uri: ...
    @typing.overload
    def __new__(cls: typing.Type[Uri], uri: str) -> Uri:...
    @typing.overload
    def __new__(cls: typing.Type[Uri], base_uri: str, relative_uri: str) -> Uri:...
    def combine_uri(self, relative_uri: str) -> typing.Optional[Uri]: ...
    def equals(self, p_uri: typing.Optional[Uri]) -> winsdk.system.Boolean: ...
    @staticmethod
    def escape_component(to_escape: str) -> str: ...
    def to_string(self) -> str: ...
    @staticmethod
    def unescape_component(to_unescape: str) -> str: ...

class WwwFormUrlDecoder(winsdk.system.Object, typing.Sequence[IWwwFormUrlDecoderEntry]):
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    @typing.overload
    def __getitem__(self, index: int) -> IWwwFormUrlDecoderEntry: ...
    @typing.overload
    def __getitem__(self, index: slice) -> winsdk.system.Array[IWwwFormUrlDecoderEntry]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WwwFormUrlDecoder: ...
    def __new__(cls: typing.Type[WwwFormUrlDecoder], query: str) -> WwwFormUrlDecoder:...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[IWwwFormUrlDecoderEntry]]: ...
    def get_at(self, index: winsdk.system.UInt32) -> typing.Optional[IWwwFormUrlDecoderEntry]: ...
    def get_first_value_by_name(self, name: str) -> str: ...
    def get_many(self, start_index: winsdk.system.UInt32, items: winsdk.system.Array[IWwwFormUrlDecoderEntry]) -> winsdk.system.UInt32: ...
    def index_of(self, value: typing.Optional[IWwwFormUrlDecoderEntry]) -> typing.Tuple[winsdk.system.Boolean, winsdk.system.UInt32]: ...

class WwwFormUrlDecoderEntry(winsdk.system.Object):
    name: str
    value: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WwwFormUrlDecoderEntry: ...

class IAsyncAction(winsdk.system.Object):
    completed: typing.Optional[AsyncActionCompletedHandler]
    error_code: HResult
    id: winsdk.system.UInt32
    status: AsyncStatus
    def __await__(self) -> typing.Generator[typing.Any, None, None]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IAsyncAction: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> None: ...

class IAsyncActionWithProgress(winsdk.system.Object, typing.Generic[TProgress]):
    progress: typing.Optional[AsyncActionProgressHandler[TProgress]]
    completed: typing.Optional[AsyncActionWithProgressCompletedHandler[TProgress]]
    error_code: HResult
    id: winsdk.system.UInt32
    status: AsyncStatus
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, key: typing.Any) -> types.GenericAlias: ...
    def __await__(self) -> typing.Generator[typing.Any, None, None]: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> None: ...

class IAsyncInfo(winsdk.system.Object):
    error_code: HResult
    id: winsdk.system.UInt32
    status: AsyncStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IAsyncInfo: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...

class IAsyncOperationWithProgress(winsdk.system.Object, typing.Generic[TResult, TProgress]):
    progress: typing.Optional[AsyncOperationProgressHandler[TResult, TProgress]]
    completed: typing.Optional[AsyncOperationWithProgressCompletedHandler[TResult, TProgress]]
    error_code: HResult
    id: winsdk.system.UInt32
    status: AsyncStatus
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, key: typing.Any) -> types.GenericAlias: ...
    def __await__(self) -> typing.Generator[typing.Any, None, TResult]: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> typing.Optional[TResult]: ...

class IAsyncOperation(winsdk.system.Object, typing.Generic[TResult]):
    completed: typing.Optional[AsyncOperationCompletedHandler[TResult]]
    error_code: HResult
    id: winsdk.system.UInt32
    status: AsyncStatus
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, key: typing.Any) -> types.GenericAlias: ...
    def __await__(self) -> typing.Generator[typing.Any, None, TResult]: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> typing.Optional[TResult]: ...

class IClosable(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IClosable: ...
    def close(self) -> None: ...

class IGetActivationFactory(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IGetActivationFactory: ...
    def get_activation_factory(self, activatable_class_id: str) -> typing.Optional[winsdk.system.Object]: ...

class IMemoryBuffer(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IMemoryBuffer: ...
    def close(self) -> None: ...
    def create_reference(self) -> typing.Optional[IMemoryBufferReference]: ...

class IMemoryBufferReference(winsdk.system.Object):
    capacity: winsdk.system.UInt32
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    def __bytes__(self) -> bytes: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IMemoryBufferReference: ...
    def close(self) -> None: ...
    def add_closed(self, handler: TypedEventHandler[IMemoryBufferReference, winsdk.system.Object]) -> EventRegistrationToken: ...
    def remove_closed(self, cookie: EventRegistrationToken) -> None: ...

class IPropertyValue(winsdk.system.Object):
    is_numeric_scalar: winsdk.system.Boolean
    type: PropertyType
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IPropertyValue: ...
    def get_boolean(self) -> winsdk.system.Boolean: ...
    def get_boolean_array(self) -> winsdk.system.Array[winsdk.system.Boolean]: ...
    def get_char16(self) -> winsdk.system.Char16: ...
    def get_char16_array(self) -> winsdk.system.Array[winsdk.system.Char16]: ...
    def get_date_time(self) -> datetime.datetime: ...
    def get_date_time_array(self) -> winsdk.system.Array[datetime.datetime]: ...
    def get_double(self) -> winsdk.system.Double: ...
    def get_double_array(self) -> winsdk.system.Array[winsdk.system.Double]: ...
    def get_guid(self) -> winsdk.system.Guid: ...
    def get_guid_array(self) -> winsdk.system.Array[winsdk.system.Guid]: ...
    def get_inspectable_array(self) -> winsdk.system.Array[winsdk.system.Object]: ...
    def get_int16(self) -> winsdk.system.Int16: ...
    def get_int16_array(self) -> winsdk.system.Array[winsdk.system.Int16]: ...
    def get_int32(self) -> winsdk.system.Int32: ...
    def get_int32_array(self) -> winsdk.system.Array[winsdk.system.Int32]: ...
    def get_int64(self) -> winsdk.system.Int64: ...
    def get_int64_array(self) -> winsdk.system.Array[winsdk.system.Int64]: ...
    def get_point(self) -> Point: ...
    def get_point_array(self) -> winsdk.system.Array[Point]: ...
    def get_rect(self) -> Rect: ...
    def get_rect_array(self) -> winsdk.system.Array[Rect]: ...
    def get_single(self) -> winsdk.system.Single: ...
    def get_single_array(self) -> winsdk.system.Array[winsdk.system.Single]: ...
    def get_size(self) -> Size: ...
    def get_size_array(self) -> winsdk.system.Array[Size]: ...
    def get_string(self) -> str: ...
    def get_string_array(self) -> winsdk.system.Array[str]: ...
    def get_time_span(self) -> datetime.timedelta: ...
    def get_time_span_array(self) -> winsdk.system.Array[datetime.timedelta]: ...
    def get_uint16(self) -> winsdk.system.UInt16: ...
    def get_uint16_array(self) -> winsdk.system.Array[winsdk.system.UInt16]: ...
    def get_uint32(self) -> winsdk.system.UInt32: ...
    def get_uint32_array(self) -> winsdk.system.Array[winsdk.system.UInt32]: ...
    def get_uint64(self) -> winsdk.system.UInt64: ...
    def get_uint64_array(self) -> winsdk.system.Array[winsdk.system.UInt64]: ...
    def get_uint8(self) -> winsdk.system.UInt8: ...
    def get_uint8_array(self) -> winsdk.system.Array[winsdk.system.UInt8]: ...

class IReferenceArray(winsdk.system.Object, typing.Generic[T]):
    value: typing.Optional[T]
    is_numeric_scalar: winsdk.system.Boolean
    type: PropertyType
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, key: typing.Any) -> types.GenericAlias: ...
    def get_boolean(self) -> winsdk.system.Boolean: ...
    def get_boolean_array(self) -> winsdk.system.Array[winsdk.system.Boolean]: ...
    def get_char16(self) -> winsdk.system.Char16: ...
    def get_char16_array(self) -> winsdk.system.Array[winsdk.system.Char16]: ...
    def get_date_time(self) -> datetime.datetime: ...
    def get_date_time_array(self) -> winsdk.system.Array[datetime.datetime]: ...
    def get_double(self) -> winsdk.system.Double: ...
    def get_double_array(self) -> winsdk.system.Array[winsdk.system.Double]: ...
    def get_guid(self) -> winsdk.system.Guid: ...
    def get_guid_array(self) -> winsdk.system.Array[winsdk.system.Guid]: ...
    def get_inspectable_array(self) -> winsdk.system.Array[winsdk.system.Object]: ...
    def get_int16(self) -> winsdk.system.Int16: ...
    def get_int16_array(self) -> winsdk.system.Array[winsdk.system.Int16]: ...
    def get_int32(self) -> winsdk.system.Int32: ...
    def get_int32_array(self) -> winsdk.system.Array[winsdk.system.Int32]: ...
    def get_int64(self) -> winsdk.system.Int64: ...
    def get_int64_array(self) -> winsdk.system.Array[winsdk.system.Int64]: ...
    def get_point(self) -> Point: ...
    def get_point_array(self) -> winsdk.system.Array[Point]: ...
    def get_rect(self) -> Rect: ...
    def get_rect_array(self) -> winsdk.system.Array[Rect]: ...
    def get_single(self) -> winsdk.system.Single: ...
    def get_single_array(self) -> winsdk.system.Array[winsdk.system.Single]: ...
    def get_size(self) -> Size: ...
    def get_size_array(self) -> winsdk.system.Array[Size]: ...
    def get_string(self) -> str: ...
    def get_string_array(self) -> winsdk.system.Array[str]: ...
    def get_time_span(self) -> datetime.timedelta: ...
    def get_time_span_array(self) -> winsdk.system.Array[datetime.timedelta]: ...
    def get_uint16(self) -> winsdk.system.UInt16: ...
    def get_uint16_array(self) -> winsdk.system.Array[winsdk.system.UInt16]: ...
    def get_uint32(self) -> winsdk.system.UInt32: ...
    def get_uint32_array(self) -> winsdk.system.Array[winsdk.system.UInt32]: ...
    def get_uint64(self) -> winsdk.system.UInt64: ...
    def get_uint64_array(self) -> winsdk.system.Array[winsdk.system.UInt64]: ...
    def get_uint8(self) -> winsdk.system.UInt8: ...
    def get_uint8_array(self) -> winsdk.system.Array[winsdk.system.UInt8]: ...

class IReference(winsdk.system.Object, typing.Generic[T]):
    value: typing.Optional[T]
    is_numeric_scalar: winsdk.system.Boolean
    type: PropertyType
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, key: typing.Any) -> types.GenericAlias: ...
    def get_boolean(self) -> winsdk.system.Boolean: ...
    def get_boolean_array(self) -> winsdk.system.Array[winsdk.system.Boolean]: ...
    def get_char16(self) -> winsdk.system.Char16: ...
    def get_char16_array(self) -> winsdk.system.Array[winsdk.system.Char16]: ...
    def get_date_time(self) -> datetime.datetime: ...
    def get_date_time_array(self) -> winsdk.system.Array[datetime.datetime]: ...
    def get_double(self) -> winsdk.system.Double: ...
    def get_double_array(self) -> winsdk.system.Array[winsdk.system.Double]: ...
    def get_guid(self) -> winsdk.system.Guid: ...
    def get_guid_array(self) -> winsdk.system.Array[winsdk.system.Guid]: ...
    def get_inspectable_array(self) -> winsdk.system.Array[winsdk.system.Object]: ...
    def get_int16(self) -> winsdk.system.Int16: ...
    def get_int16_array(self) -> winsdk.system.Array[winsdk.system.Int16]: ...
    def get_int32(self) -> winsdk.system.Int32: ...
    def get_int32_array(self) -> winsdk.system.Array[winsdk.system.Int32]: ...
    def get_int64(self) -> winsdk.system.Int64: ...
    def get_int64_array(self) -> winsdk.system.Array[winsdk.system.Int64]: ...
    def get_point(self) -> Point: ...
    def get_point_array(self) -> winsdk.system.Array[Point]: ...
    def get_rect(self) -> Rect: ...
    def get_rect_array(self) -> winsdk.system.Array[Rect]: ...
    def get_single(self) -> winsdk.system.Single: ...
    def get_single_array(self) -> winsdk.system.Array[winsdk.system.Single]: ...
    def get_size(self) -> Size: ...
    def get_size_array(self) -> winsdk.system.Array[Size]: ...
    def get_string(self) -> str: ...
    def get_string_array(self) -> winsdk.system.Array[str]: ...
    def get_time_span(self) -> datetime.timedelta: ...
    def get_time_span_array(self) -> winsdk.system.Array[datetime.timedelta]: ...
    def get_uint16(self) -> winsdk.system.UInt16: ...
    def get_uint16_array(self) -> winsdk.system.Array[winsdk.system.UInt16]: ...
    def get_uint32(self) -> winsdk.system.UInt32: ...
    def get_uint32_array(self) -> winsdk.system.Array[winsdk.system.UInt32]: ...
    def get_uint64(self) -> winsdk.system.UInt64: ...
    def get_uint64_array(self) -> winsdk.system.Array[winsdk.system.UInt64]: ...
    def get_uint8(self) -> winsdk.system.UInt8: ...
    def get_uint8_array(self) -> winsdk.system.Array[winsdk.system.UInt8]: ...

class IStringable(winsdk.system.Object):
    def __str__(self) -> str: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IStringable: ...
    def to_string(self) -> str: ...

class IWwwFormUrlDecoderEntry(winsdk.system.Object):
    name: str
    value: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWwwFormUrlDecoderEntry: ...

AsyncActionCompletedHandler = typing.Callable[[IAsyncAction, AsyncStatus], None]

AsyncActionProgressHandler = typing.Callable[[IAsyncActionWithProgress[TProgress], typing.Optional[TProgress]], None]

AsyncActionWithProgressCompletedHandler = typing.Callable[[IAsyncActionWithProgress[TProgress], AsyncStatus], None]

AsyncOperationCompletedHandler = typing.Callable[[IAsyncOperation[TResult], AsyncStatus], None]

AsyncOperationProgressHandler = typing.Callable[[IAsyncOperationWithProgress[TResult, TProgress], typing.Optional[TProgress]], None]

AsyncOperationWithProgressCompletedHandler = typing.Callable[[IAsyncOperationWithProgress[TResult, TProgress], AsyncStatus], None]

DeferralCompletedHandler = typing.Callable[[], None]

EventHandler = typing.Callable[[typing.Optional[winsdk.system.Object], typing.Optional[T]], None]

TypedEventHandler = typing.Callable[[typing.Optional[TSender], typing.Optional[TResult]], None]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Storage.BulkAccess")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.fileproperties
except ImportError:
    pass

try:
    import winsdk.windows.storage.search
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass


FileInformation = _ns_module.FileInformation
FileInformationFactory = _ns_module.FileInformationFactory
FolderInformation = _ns_module.FolderInformation
IStorageItemInformation = _ns_module.IStorageItemInformation



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.AI.MachineLearning.Preview")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.graphics.imaging
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class FeatureElementKindPreview(enum.IntEnum):
    UNDEFINED = 0
    FLOAT = 1
    UINT8 = 2
    INT8 = 3
    UINT16 = 4
    INT16 = 5
    INT32 = 6
    INT64 = 7
    STRING = 8
    BOOLEAN = 9
    FLOAT16 = 10
    DOUBLE = 11
    UINT32 = 12
    UINT64 = 13
    COMPLEX64 = 14
    COMPLEX128 = 15

class LearningModelDeviceKindPreview(enum.IntEnum):
    LEARNING_DEVICE_ANY = 0
    LEARNING_DEVICE_CPU = 1
    LEARNING_DEVICE_GPU = 2
    LEARNING_DEVICE_NPU = 3
    LEARNING_DEVICE_DSP = 4
    LEARNING_DEVICE_FPGA = 5

class LearningModelFeatureKindPreview(enum.IntEnum):
    UNDEFINED = 0
    TENSOR = 1
    SEQUENCE = 2
    MAP = 3
    IMAGE = 4

_ns_module._register_FeatureElementKindPreview(FeatureElementKindPreview)
_ns_module._register_LearningModelDeviceKindPreview(LearningModelDeviceKindPreview)
_ns_module._register_LearningModelFeatureKindPreview(LearningModelFeatureKindPreview)

ImageVariableDescriptorPreview = _ns_module.ImageVariableDescriptorPreview
InferencingOptionsPreview = _ns_module.InferencingOptionsPreview
LearningModelBindingPreview = _ns_module.LearningModelBindingPreview
LearningModelDescriptionPreview = _ns_module.LearningModelDescriptionPreview
LearningModelEvaluationResultPreview = _ns_module.LearningModelEvaluationResultPreview
LearningModelPreview = _ns_module.LearningModelPreview
LearningModelVariableDescriptorPreview = _ns_module.LearningModelVariableDescriptorPreview
MapVariableDescriptorPreview = _ns_module.MapVariableDescriptorPreview
SequenceVariableDescriptorPreview = _ns_module.SequenceVariableDescriptorPreview
TensorVariableDescriptorPreview = _ns_module.TensorVariableDescriptorPreview
ILearningModelVariableDescriptorPreview = _ns_module.ILearningModelVariableDescriptorPreview



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.ApplicationSettings")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.security.credentials
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui.popups
except ImportError:
    pass

class SettingsEdgeLocation(enum.IntEnum):
    RIGHT = 0
    LEFT = 1

class SupportedWebAccountActions(enum.IntFlag):
    NONE = 0
    RECONNECT = 0x1
    REMOVE = 0x2
    VIEW_DETAILS = 0x4
    MANAGE = 0x8
    MORE = 0x10

class WebAccountAction(enum.IntEnum):
    RECONNECT = 0
    REMOVE = 1
    VIEW_DETAILS = 2
    MANAGE = 3
    MORE = 4

_ns_module._register_SettingsEdgeLocation(SettingsEdgeLocation)
_ns_module._register_SupportedWebAccountActions(SupportedWebAccountActions)
_ns_module._register_WebAccountAction(WebAccountAction)

AccountsSettingsPane = _ns_module.AccountsSettingsPane
AccountsSettingsPaneCommandsRequestedEventArgs = _ns_module.AccountsSettingsPaneCommandsRequestedEventArgs
AccountsSettingsPaneEventDeferral = _ns_module.AccountsSettingsPaneEventDeferral
CredentialCommand = _ns_module.CredentialCommand
SettingsCommand = _ns_module.SettingsCommand
SettingsPane = _ns_module.SettingsPane
SettingsPaneCommandsRequest = _ns_module.SettingsPaneCommandsRequest
SettingsPaneCommandsRequestedEventArgs = _ns_module.SettingsPaneCommandsRequestedEventArgs
WebAccountCommand = _ns_module.WebAccountCommand
WebAccountInvokedArgs = _ns_module.WebAccountInvokedArgs
WebAccountProviderCommand = _ns_module.WebAccountProviderCommand



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Security.Cryptography")

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class BinaryStringEncoding(enum.IntEnum):
    UTF8 = 0
    UTF16_L_E = 1
    UTF16_B_E = 2

_ns_module._register_BinaryStringEncoding(BinaryStringEncoding)

CryptographicBuffer = _ns_module.CryptographicBuffer



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.ui.input
import winsdk.windows.ui.windowmanagement

Self = typing.TypeVar('Self')

class InputActivationListenerPreview(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InputActivationListenerPreview: ...
    @staticmethod
    def create_for_application_window(window: typing.Optional[winsdk.windows.ui.windowmanagement.AppWindow]) -> typing.Optional[winsdk.windows.ui.input.InputActivationListener]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage
import winsdk.windows.system

class AccessCacheOptions(enum.IntFlag):
    NONE = 0
    DISALLOW_USER_INPUT = 0x1
    FAST_LOCATIONS_ONLY = 0x2
    USE_READ_ONLY_CACHED_COPY = 0x4
    SUPPRESS_ACCESS_TIME_UPDATE = 0x8

class RecentStorageItemVisibility(enum.IntEnum):
    APP_ONLY = 0
    APP_AND_SYSTEM = 1

Self = typing.TypeVar('Self')

class AccessListEntry:
    token: str
    metadata: str
    def __new__(cls: typing.Type[AccessListEntry], token: str, metadata: str) -> AccessListEntry: ...

class AccessListEntryView(winsdk.system.Object, typing.Sequence[AccessListEntry]):
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    @typing.overload
    def __getitem__(self, index: int) -> AccessListEntry: ...
    @typing.overload
    def __getitem__(self, index: slice) -> winsdk.system.Array[AccessListEntry]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AccessListEntryView: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[AccessListEntry]]: ...
    def get_at(self, index: winsdk.system.UInt32) -> AccessListEntry: ...
    def get_many(self, start_index: winsdk.system.UInt32, items: winsdk.system.Array[AccessListEntry]) -> winsdk.system.UInt32: ...
    def index_of(self, value: AccessListEntry) -> typing.Tuple[winsdk.system.Boolean, winsdk.system.UInt32]: ...

class ItemRemovedEventArgs(winsdk.system.Object):
    removed_entry: AccessListEntry
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ItemRemovedEventArgs: ...

class StorageApplicationPermissions(winsdk.system.Object):
    future_access_list: typing.ClassVar[typing.Optional[StorageItemAccessList]]
    most_recently_used_list: typing.ClassVar[typing.Optional[StorageItemMostRecentlyUsedList]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorageApplicationPermissions: ...
    @staticmethod
    def get_future_access_list_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[StorageItemAccessList]: ...
    @staticmethod
    def get_most_recently_used_list_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[StorageItemMostRecentlyUsedList]: ...

class StorageItemAccessList(winsdk.system.Object):
    entries: typing.Optional[AccessListEntryView]
    maximum_items_allowed: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorageItemAccessList: ...
    @typing.overload
    def add(self, file: typing.Optional[winsdk.windows.storage.IStorageItem]) -> str: ...
    @typing.overload
    def add(self, file: typing.Optional[winsdk.windows.storage.IStorageItem], metadata: str) -> str: ...
    @typing.overload
    def add_or_replace(self, token: str, file: typing.Optional[winsdk.windows.storage.IStorageItem]) -> None: ...
    @typing.overload
    def add_or_replace(self, token: str, file: typing.Optional[winsdk.windows.storage.IStorageItem], metadata: str) -> None: ...
    def check_access(self, file: typing.Optional[winsdk.windows.storage.IStorageItem]) -> winsdk.system.Boolean: ...
    def clear(self) -> None: ...
    def contains_item(self, token: str) -> winsdk.system.Boolean: ...
    @typing.overload
    def get_file_async(self, token: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageFile]: ...
    @typing.overload
    def get_file_async(self, token: str, options: AccessCacheOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageFile]: ...
    @typing.overload
    def get_folder_async(self, token: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageFolder]: ...
    @typing.overload
    def get_folder_async(self, token: str, options: AccessCacheOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageFolder]: ...
    @typing.overload
    def get_item_async(self, token: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.IStorageItem]: ...
    @typing.overload
    def get_item_async(self, token: str, options: AccessCacheOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.IStorageItem]: ...
    def remove(self, token: str) -> None: ...

class StorageItemMostRecentlyUsedList(winsdk.system.Object):
    entries: typing.Optional[AccessListEntryView]
    maximum_items_allowed: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorageItemMostRecentlyUsedList: ...
    @typing.overload
    def add(self, file: typing.Optional[winsdk.windows.storage.IStorageItem]) -> str: ...
    @typing.overload
    def add(self, file: typing.Optional[winsdk.windows.storage.IStorageItem], metadata: str) -> str: ...
    @typing.overload
    def add(self, file: typing.Optional[winsdk.windows.storage.IStorageItem], metadata: str, visibility: RecentStorageItemVisibility) -> str: ...
    @typing.overload
    def add_or_replace(self, token: str, file: typing.Optional[winsdk.windows.storage.IStorageItem]) -> None: ...
    @typing.overload
    def add_or_replace(self, token: str, file: typing.Optional[winsdk.windows.storage.IStorageItem], metadata: str) -> None: ...
    @typing.overload
    def add_or_replace(self, token: str, file: typing.Optional[winsdk.windows.storage.IStorageItem], metadata: str, visibility: RecentStorageItemVisibility) -> None: ...
    def check_access(self, file: typing.Optional[winsdk.windows.storage.IStorageItem]) -> winsdk.system.Boolean: ...
    def clear(self) -> None: ...
    def contains_item(self, token: str) -> winsdk.system.Boolean: ...
    @typing.overload
    def get_file_async(self, token: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageFile]: ...
    @typing.overload
    def get_file_async(self, token: str, options: AccessCacheOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageFile]: ...
    @typing.overload
    def get_folder_async(self, token: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageFolder]: ...
    @typing.overload
    def get_folder_async(self, token: str, options: AccessCacheOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageFolder]: ...
    @typing.overload
    def get_item_async(self, token: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.IStorageItem]: ...
    @typing.overload
    def get_item_async(self, token: str, options: AccessCacheOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.IStorageItem]: ...
    def remove(self, token: str) -> None: ...
    def add_item_removed(self, handler: winsdk.windows.foundation.TypedEventHandler[StorageItemMostRecentlyUsedList, ItemRemovedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_item_removed(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class IStorageItemAccessList(winsdk.system.Object):
    entries: typing.Optional[AccessListEntryView]
    maximum_items_allowed: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IStorageItemAccessList: ...
    @typing.overload
    def add(self, file: typing.Optional[winsdk.windows.storage.IStorageItem]) -> str: ...
    @typing.overload
    def add(self, file: typing.Optional[winsdk.windows.storage.IStorageItem], metadata: str) -> str: ...
    @typing.overload
    def add_or_replace(self, token: str, file: typing.Optional[winsdk.windows.storage.IStorageItem]) -> None: ...
    @typing.overload
    def add_or_replace(self, token: str, file: typing.Optional[winsdk.windows.storage.IStorageItem], metadata: str) -> None: ...
    def check_access(self, file: typing.Optional[winsdk.windows.storage.IStorageItem]) -> winsdk.system.Boolean: ...
    def clear(self) -> None: ...
    def contains_item(self, token: str) -> winsdk.system.Boolean: ...
    @typing.overload
    def get_file_async(self, token: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageFile]: ...
    @typing.overload
    def get_file_async(self, token: str, options: AccessCacheOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageFile]: ...
    @typing.overload
    def get_folder_async(self, token: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageFolder]: ...
    @typing.overload
    def get_folder_async(self, token: str, options: AccessCacheOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageFolder]: ...
    @typing.overload
    def get_item_async(self, token: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.IStorageItem]: ...
    @typing.overload
    def get_item_async(self, token: str, options: AccessCacheOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.IStorageItem]: ...
    def remove(self, token: str) -> None: ...

